@@ -41,26 +41,12 @@
  * the plugins.
  */
 
-#include "config.h"
-
 #include <gmodule.h>
 #include <mission-control-plugins/mission-control-plugins.h>
-#include <mission-control-plugins/debug.h>
+#include <mission-control-plugins/debug-internal.h>
 
 static gboolean debugging = FALSE;
 
-#undef  DEBUG
-#define DEBUG(format, ...) \
-  G_STMT_START { if (debugging || mcp_is_debugging (MCP_DEBUG_LOADER))  \
-      g_debug ("%s " format, G_STRLOC, ##__VA_ARGS__); } G_STMT_END
-
-/* Android's build system prefixes the plugins with lib */
-#ifndef __BIONIC__
-#define PLUGIN_PREFIX "mcp-"
-#else
-#define PLUGIN_PREFIX "libmcp-"
-#endif
-
 /**
  * mcp_set_debug:
  * @debug: whether to log debug output
@@ -74,6 +60,25 @@ mcp_set_debug (gboolean debug)
   debugging = debug;
 }
 
+gboolean
+_mcp_is_debugging (void)
+{
+  return debugging;
+}
+
+void
+_mcp_debug (const gchar *format, ...)
+{
+  if (debugging)
+    {
+      va_list args;
+
+      va_start (args, format);
+      g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, format, args);
+      va_end (args);
+    }
+}
+
 static GList *plugins = NULL;
 
 /**
@@ -155,9 +160,9 @@ mcp_read_dir (const gchar *path)
       gchar *full_path;
       GModule *module;
 
-      if (!g_str_has_prefix (entry, PLUGIN_PREFIX))
+      if (!g_str_has_prefix (entry, "mcp-"))
         {
-          DEBUG ("%s isn't a plugin (doesn't start with " PLUGIN_PREFIX ")", entry);
+          DEBUG ("%s isn't a plugin (doesn't start with mcp-)", entry);
           continue;
         }
 
