@@ -28,6 +28,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include "mcd-controller.h"
 
 G_BEGIN_DECLS
 #define MCD_TYPE_MASTER         (mcd_master_get_type ())
@@ -39,27 +40,38 @@ G_BEGIN_DECLS
 
 typedef struct _McdMaster McdMaster;
 typedef struct _McdMasterClass McdMasterClass;
-typedef struct _McdMasterPrivate McdMasterPrivate;
 
 #include <mcd-manager.h>
 #include <mcd-connection.h>
+#include <mcd-connection-plugin.h>
 
 struct _McdMaster
 {
-    McdOperation parent;
-    McdMasterPrivate *priv;
+    McdController parent;
 };
 
 struct _McdMasterClass
 {
-    McdOperationClass parent_class;
+    McdControllerClass parent_class;
+    McdManager *(*create_manager) (McdMaster *master,
+                                   const gchar *unique_name);
+    void (*_mc_reserved1) (void);
+    void (*_mc_reserved2) (void);
+    void (*_mc_reserved3) (void);
+    void (*_mc_reserved4) (void);
+    void (*_mc_reserved5) (void);
+    void (*_mc_reserved6) (void);
 };
 
 GType mcd_master_get_type (void);
 McdMaster *mcd_master_get_default (void);
 
+McdDispatcher *mcd_master_get_dispatcher (McdMaster *master);
 TpDBusDaemon *mcd_master_get_dbus_daemon (McdMaster *master);
-void mcd_master_shutdown (McdMaster *self, const gchar *reason);
+
+gboolean mcd_master_has_low_memory (McdMaster *master);
+void mcd_master_set_low_memory (McdMaster *master, gboolean low_memory);
+void mcd_master_set_idle (McdMaster *master, gboolean idle);
 
 G_END_DECLS
 #endif /* MCD_MASTER_H */
