@@ -29,9 +29,8 @@
 
 #include <glib.h>
 #include <glib-object.h>
-
-#include <telepathy-glib/telepathy-glib.h>
-#include <telepathy-glib/telepathy-glib-dbus.h>
+#include <telepathy-glib/dbus.h>
+#include <telepathy-glib/gtypes.h>
 
 G_BEGIN_DECLS
 
@@ -48,14 +47,13 @@ void _mcd_object_call_on_struct_when_ready (gpointer object, gpointer strukt,
                                             gpointer user_data);
 void _mcd_object_ready (gpointer object, GQuark quark, const GError *error);
 
+G_GNUC_INTERNAL
+gboolean _mcd_file_set_contents (const gchar *filename, const gchar *contents,
+                                 gssize length, GError **error);
 G_GNUC_INTERNAL
 void _mcd_ext_register_dbus_glib_marshallers (void);
 
-gboolean mcd_ensure_directory (const gchar *dir, GError **error);
-
 G_GNUC_INTERNAL int _mcd_chmod_private (const gchar *filename);
 
-gboolean mcd_nullable_variant_equal (GVariant *a, GVariant *b);
-
 G_END_DECLS
 #endif /* MCD_MISC_H */
