@@ -20,13 +20,15 @@
  *
  */
 
-#include "config.h"
-
 #include "request.h"
 
 #include <dbus/dbus-glib.h>
-#include <telepathy-glib/telepathy-glib.h>
-#include <telepathy-glib/telepathy-glib-dbus.h>
+#include <telepathy-glib/dbus-properties-mixin.h>
+#include <telepathy-glib/gtypes.h>
+#include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/svc-channel-request.h>
+#include <telepathy-glib/svc-generic.h>
+#include <telepathy-glib/util.h>
 
 #include "mcd-account-priv.h"
 #include "mcd-connection-priv.h"
@@ -35,6 +37,7 @@
 #include "plugin-loader.h"
 #include "plugin-request.h"
 #include "_gen/interfaces.h"
+#include "_gen/svc-request.h"
 
 enum {
     PROP_0,
@@ -103,7 +106,7 @@ G_DEFINE_TYPE_WITH_CODE (McdRequest, _mcd_request, G_TYPE_OBJECT,
     G_IMPLEMENT_INTERFACE (TP_TYPE_SVC_DBUS_PROPERTIES,
                            tp_dbus_properties_mixin_iface_init))
 
-#define REQUEST_OBJ_BASE "/org/freedesktop/Telepathy/ChannelDispatcher/Request"
+#define REQUEST_OBJ_BASE "/com/nokia/MissionControl/requests/r"
 
 static guint last_req_id = 1;
 
@@ -274,15 +277,6 @@ _mcd_request_dispose (GObject *object)
 
   DEBUG ("%p", object);
 
-  /* shouldn't ever actually get this far with a blocked account, *
-   * but we have to clear the lock if we do or we'll deadlock     */
-  if (_mcd_request_is_internal (self) && self->account != NULL)
-    {
-      const gchar *path = mcd_account_get_object_path (self->account);
-      _mcd_request_unblock_account (path);
-      g_warning ("internal request disposed without being handled or failed");
-    }
-
   tp_clear_object (&self->account);
   tp_clear_object (&self->clients);
   tp_clear_object (&self->predicted_handler);
@@ -461,7 +455,6 @@ _mcd_request_handle_internally (McdRequest *self,
 {
   if (self->internal_handler != NULL)
     {
-      DEBUG ("Handling request %p, channel %p internally", self, channel);
       self->internal_handler (self, channel, self->internal_handler_data,
           close_after);
 
@@ -688,7 +681,7 @@ _mcd_request_proceed (McdRequest *self,
 
   if (self->proceeding)
     {
-      GError na = { TP_ERROR, TP_ERROR_NOT_AVAILABLE,
+      GError na = { TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
           "Proceed has already been called; stop calling it" };
 
       if (context != NULL)
@@ -762,19 +755,6 @@ _mcd_request_get_properties (McdRequest *self)
   return self->properties;
 }
 
-GVariant *
-mcd_request_dup_properties (McdRequest *self)
-{
-  GValue value = G_VALUE_INIT;
-  GVariant *ret;
-
-  g_value_init (&value, TP_HASH_TYPE_STRING_VARIANT_MAP);
-  g_value_set_boxed (&value, self->properties);
-  ret = dbus_g_value_build_g_variant (&value);
-  g_value_unset (&value);
-  return g_variant_ref_sink (ret);
-}
-
 void
 _mcd_request_start_delay (McdRequest *self)
 {
@@ -814,27 +794,18 @@ _mcd_request_set_success (McdRequest *self,
        * for now */
       GHashTable *future_conn_props = g_hash_table_new (g_str_hash,
           g_str_equal);
-      GVariant *variant;
-      GValue value = G_VALUE_INIT;
-
       DEBUG ("Request succeeded");
       self->is_complete = TRUE;
       self->cancellable = FALSE;
 
-      variant = tp_channel_dup_immutable_properties (channel);
-      dbus_g_value_parse_g_variant (variant, &value);
-      g_assert (G_VALUE_HOLDS (&value, TP_HASH_TYPE_STRING_VARIANT_MAP));
-
       tp_svc_channel_request_emit_succeeded_with_channel (self,
-          tp_proxy_get_object_path (tp_channel_get_connection (channel)),
+          tp_proxy_get_object_path (tp_channel_borrow_connection (channel)),
           future_conn_props,
           tp_proxy_get_object_path (channel),
-          g_value_get_boxed (&value));
+          tp_channel_borrow_immutable_properties (channel));
       tp_svc_channel_request_emit_succeeded (self);
 
       g_hash_table_unref (future_conn_props);
-      g_value_unset (&value);
-      g_variant_unref (variant);
 
       _mcd_request_clean_up (self);
     }
@@ -975,7 +946,7 @@ _mcd_request_cancel (McdRequest *self,
     }
   else
     {
-      g_set_error (error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
+      g_set_error (error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
           "ChannelRequest is no longer cancellable");
       return FALSE;
     }
@@ -985,7 +956,6 @@ static TpClient *
 guess_request_handler (McdRequest *self)
 {
   GList *sorted_handlers;
-  GVariant *properties;
 
   if (!tp_str_empty (self->preferred_handler))
     {
@@ -996,11 +966,9 @@ guess_request_handler (McdRequest *self)
             return (TpClient *) client;
     }
 
-  properties = mcd_request_dup_properties (self);
   sorted_handlers = _mcd_client_registry_list_possible_handlers (
-      self->clients, self->preferred_handler, properties,
+      self->clients, self->preferred_handler, self->properties,
       NULL, NULL);
-  g_variant_unref (properties);
 
   if (sorted_handlers != NULL)
     {
