@@ -1,5 +1,5 @@
 # Copyright (C) 2009 Nokia Corporation
-# Copyright (C) 2009-2012 Collabora Ltd.
+# Copyright (C) 2009 Collabora Ltd.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -21,16 +21,23 @@ import dbus
 import dbus.service
 
 from servicetest import EventPattern, tp_name_prefix, tp_path_prefix, \
-        call_async, assertEquals, assertContains
-from mctest import exec_test, create_fakecm_account, AccountManager
+        call_async
+from mctest import exec_test, create_fakecm_account, get_account_manager
 import constants as cs
 
 def test(q, bus, mc):
-    account_manager = AccountManager(bus)
+    # Get the AccountManager interface
+    account_manager = get_account_manager(bus)
+    account_manager_iface = dbus.Interface(account_manager, cs.AM)
+
+    # Introspect AccountManager for debugging purpose
+    account_manager_introspected = account_manager.Introspect(
+            dbus_interface=cs.INTROSPECTABLE_IFACE)
+    #print account_manager_introspected
 
     # Check AccountManager has D-Bus property interface
-    call_async(q, account_manager.Properties, 'GetAll', cs.AM)
-    properties, = q.expect('dbus-return', method='GetAll').value
+    properties = account_manager.GetAll(cs.AM,
+            dbus_interface=cs.PROPERTIES_IFACE)
     assert properties is not None
     assert properties.get('ValidAccounts') == [], \
         properties.get('ValidAccounts')
@@ -39,23 +46,28 @@ def test(q, bus, mc):
     interfaces = properties.get('Interfaces')
     supported = properties.get('SupportedAccountProperties')
 
+    # assert that current functionality exists
+    assert cs.AM_IFACE_NOKIA_QUERY in interfaces, interfaces
+
     assert (cs.ACCOUNT + '.AutomaticPresence') in supported
     assert (cs.ACCOUNT + '.Enabled') in supported
     assert (cs.ACCOUNT + '.Icon') in supported
     assert (cs.ACCOUNT + '.Nickname') in supported
     assert (cs.ACCOUNT + '.ConnectAutomatically') in supported
     assert (cs.ACCOUNT_IFACE_AVATAR + '.Avatar') in supported
+    assert (cs.ACCOUNT_IFACE_NOKIA_COMPAT + '.Profile') in supported
+    assert (cs.ACCOUNT_IFACE_NOKIA_COMPAT + '.SecondaryVCardFields') in supported
     assert (cs.ACCOUNT_IFACE_NOKIA_CONDITIONS + '.Condition') in supported
 
     assert (cs.ACCOUNT + '.RequestedPresence') in supported
-    assert (cs.ACCOUNT + '.Supersedes') in supported
-    assertContains(cs.ACCOUNT + '.Service', supported)
 
     params = dbus.Dictionary({"account": "anarki@example.com",
         "password": "secrecy"}, signature='sv')
 
     cm_name_ref = dbus.service.BusName(cs.tp_name_prefix +
             '.ConnectionManager.fakecm', bus=bus)
+    account_manager = bus.get_object(cs.AM, cs.AM_PATH)
+    am_iface = dbus.Interface(account_manager, cs.AM)
 
     creation_properties = dbus.Dictionary({
         cs.ACCOUNT + '.Enabled': True,
@@ -68,18 +80,16 @@ def test(q, bus, mc):
         cs.ACCOUNT + '.Icon': 'quake3arena',
         cs.ACCOUNT + '.Nickname': 'AnArKi',
         cs.ACCOUNT + '.ConnectAutomatically': True,
-        cs.ACCOUNT_IFACE_AVATAR + '.Avatar': (dbus.ByteArray(b'foo'),
+        cs.ACCOUNT_IFACE_AVATAR + '.Avatar': (dbus.ByteArray('foo'),
             'image/jpeg'),
+        cs.ACCOUNT_IFACE_NOKIA_COMPAT + '.Profile': 'openarena',
+        cs.ACCOUNT_IFACE_NOKIA_COMPAT + '.SecondaryVCardFields':
+            dbus.Array(['x-ioquake3', 'x-quake3'], signature='s'),
         cs.ACCOUNT_IFACE_NOKIA_CONDITIONS + '.Condition':
             dbus.Dictionary({ 'has-quad-damage': ':y' }, signature='ss'),
-        cs.ACCOUNT + '.Supersedes': dbus.Array([
-            cs.ACCOUNT_PATH_PREFIX + 'q1/q1/Ranger',
-            cs.ACCOUNT_PATH_PREFIX + 'q2/q2/Grunt',
-            ], signature='o'),
-        cs.ACCOUNT + '.Service': 'arena',
         }, signature='sv')
 
-    call_async(q, account_manager, 'CreateAccount',
+    call_async(q, am_iface, 'CreateAccount',
             'fakecm',
             'fakeprotocol',
             'fakeaccount',
@@ -123,18 +133,16 @@ def test(q, bus, mc):
         properties.get('Icon')
     assert properties.get('Nickname') == 'AnArKi', \
         properties.get('Nickname')
-    assertEquals(
-            dbus.Array([
-                cs.ACCOUNT_PATH_PREFIX + 'q1/q1/Ranger',
-                cs.ACCOUNT_PATH_PREFIX + 'q2/q2/Grunt',
-                ], signature='o'),
-        properties.get('Supersedes'))
-    assertEquals('arena', properties.get('Service'))
 
     properties = account_props.GetAll(cs.ACCOUNT_IFACE_AVATAR)
     assert properties.get('Avatar') == ([ord('f'), ord('o'), ord('o')],
             'image/jpeg')
 
+    properties = account_props.GetAll(cs.ACCOUNT_IFACE_NOKIA_COMPAT)
+    assert properties.get('Profile') == 'openarena'
+    assert sorted(properties.get('SecondaryVCardFields')) == \
+            ['x-ioquake3', 'x-quake3']
+
     properties = account_props.GetAll(cs.ACCOUNT_IFACE_NOKIA_CONDITIONS)
     assert properties.get('Condition') == {
             'has-quad-damage': ':y',
@@ -144,7 +152,7 @@ def test(q, bus, mc):
 
     creation_properties2 = creation_properties.copy()
     creation_properties2[cs.ACCOUNT + '.NonExistent'] = 'foo'
-    call_async(q, account_manager, 'CreateAccount',
+    call_async(q, am_iface, 'CreateAccount',
             'fakecm',
             'fakeprotocol',
             'fakeaccount',
@@ -154,7 +162,7 @@ def test(q, bus, mc):
 
     params2 = params.copy()
     params2['fake_param'] = 'foo'
-    call_async(q, account_manager, 'CreateAccount',
+    call_async(q, am_iface, 'CreateAccount',
             'fakecm',
             'fakeprotocol',
             'fakeaccount',
