@@ -17,13 +17,19 @@
 # 02110-1301 USA
 
 import dbus
+import dbus
+import dbus.service
 
 from servicetest import (EventPattern, tp_name_prefix, tp_path_prefix,
-        call_async, assertEquals)
-from mctest import exec_test, SimulatedConnection, create_fakecm_account
+        call_async, sync_dbus, assertEquals)
+from mctest import exec_test, SimulatedConnection, create_fakecm_account,\
+        SimulatedChannel
 import constants as cs
 
 def test(q, bus, mc):
+    cm_name_ref = dbus.service.BusName(
+            tp_name_prefix + '.ConnectionManager.fakecm', bus=bus)
+
     # Create an account. We're setting register=True here to verify
     # that after one successful connection, it'll be removed (fd.o #28118).
     params = dbus.Dictionary({"account": "someguy@example.com",
@@ -31,17 +37,23 @@ def test(q, bus, mc):
         "register": True}, signature='sv')
     (cm_name_ref, account) = create_fakecm_account(q, bus, mc, params)
 
-    call_async(q, account.Properties, 'Set', cs.ACCOUNT, 'Enabled', False)
+    account_iface = dbus.Interface(account, cs.ACCOUNT)
+    account_props = dbus.Interface(account, cs.PROPERTIES_IFACE)
+
+    call_async(q, account, 'Set', cs.ACCOUNT, 'Enabled', False,
+            dbus_interface=cs.PROPERTIES_IFACE)
     q.expect('dbus-return', method='Set')
 
     # Enable the account
-    call_async(q, account.Properties, 'Set', cs.ACCOUNT, 'Enabled', True)
+    call_async(q, account, 'Set', cs.ACCOUNT, 'Enabled', True,
+            dbus_interface=cs.PROPERTIES_IFACE)
 
     # Set online presence
     presence = dbus.Struct((dbus.UInt32(cs.PRESENCE_TYPE_BUSY), 'busy',
             'Fixing MC bugs'), signature='uss')
-    call_async(q, account.Properties, 'Set', cs.ACCOUNT,
-            'RequestedPresence', presence)
+    call_async(q, account, 'Set', cs.ACCOUNT,
+            'RequestedPresence', presence,
+            dbus_interface=cs.PROPERTIES_IFACE)
 
     e = q.expect('dbus-method-call', method='RequestConnection',
             args=['fakeprotocol', params],
@@ -120,12 +132,7 @@ def test(q, bus, mc):
     assertEquals(cs.CONN_STATUS_REASON_REQUESTED,
         connecting.args[0].get('ConnectionStatusReason'))
 
-    # The object path needs to be different from the first simulated
-    # connection which we made above, because the object isn't removed
-    # from this bus and it's actually hard to do so because it's not
-    # really on a bus, it's on the queue. So let's just change the
-    # object path and it's fine.
-    conn = SimulatedConnection(q, bus, 'fakecm', 'fakeprotocol', 'second',
+    conn = SimulatedConnection(q, bus, 'fakecm', 'fakeprotocol', '_',
             'myself', has_presence=True)
 
     q.dbus_return(e.message, conn.bus_name, conn.object_path, signature='so')
@@ -154,10 +161,10 @@ def test(q, bus, mc):
         connecting.args[0].get('ConnectionStatusReason'))
 
     assertEquals('com.example.My.Network.Is.Full.Of.Eels',
-            account.Properties.Get(cs.ACCOUNT, 'ConnectionError'))
+            account_props.Get(cs.ACCOUNT, 'ConnectionError'))
     assertEquals(
             {'eels': 23, 'capacity': 23, 'debug-message': 'Too many eels'},
-            account.Properties.Get(cs.ACCOUNT, 'ConnectionErrorDetails'))
+            account_props.Get(cs.ACCOUNT, 'ConnectionErrorDetails'))
 
     # Connect succeeds
     conn.StatusChanged(cs.CONN_STATUS_CONNECTED, cs.CONN_STATUS_REASON_NONE)
@@ -183,8 +190,8 @@ def test(q, bus, mc):
     assertEquals(cs.CONN_STATUS_REASON_REQUESTED,
         connected.args[0].get('ConnectionStatusReason'))
 
-    assertEquals('', account.Properties.Get(cs.ACCOUNT, 'ConnectionError'))
-    assertEquals({}, account.Properties.Get(cs.ACCOUNT, 'ConnectionErrorDetails'))
+    assertEquals('', account_props.Get(cs.ACCOUNT, 'ConnectionError'))
+    assertEquals({}, account_props.Get(cs.ACCOUNT, 'ConnectionErrorDetails'))
 
 if __name__ == '__main__':
     exec_test(test, {})
