@@ -19,50 +19,17 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#undef MC_DISABLE_DEPRECATED
-#include "config.h"
-
 #include <mission-control-plugins/mission-control-plugins.h>
 
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
-#include <telepathy-glib/telepathy-glib.h>
-#include <telepathy-glib/telepathy-glib-dbus.h>
-
-#include "dbus-account-plugin.h"
+#include <telepathy-glib/dbus.h>
+#include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/util.h>
 
 #define DEBUG g_debug
 
-/* ------ TestNoOpPlugin -------------------------------------- */
-/* doesn't implement anything, to check that NULL pointers are OK */
-
-typedef struct {
-    GObject parent;
-} TestNoOpPlugin;
-
-typedef struct {
-    GObjectClass parent_class;
-} TestNoOpPluginClass;
-
-GType test_no_op_plugin_get_type (void) G_GNUC_CONST;
-
-G_DEFINE_TYPE_WITH_CODE (TestNoOpPlugin, test_no_op_plugin,
-    G_TYPE_OBJECT,
-    G_IMPLEMENT_INTERFACE (MCP_TYPE_DBUS_ACL, NULL);
-    G_IMPLEMENT_INTERFACE (MCP_TYPE_REQUEST_POLICY, NULL);
-    G_IMPLEMENT_INTERFACE (MCP_TYPE_DISPATCH_OPERATION_POLICY, NULL))
-
-static void
-test_no_op_plugin_init (TestNoOpPlugin *self)
-{
-}
-
-static void
-test_no_op_plugin_class_init (TestNoOpPluginClass *cls)
-{
-}
-
 /* ------ TestPermissionPlugin -------------------------------------- */
 
 typedef struct {
@@ -98,7 +65,6 @@ test_permission_plugin_class_init (TestPermissionPluginClass *cls)
 typedef struct {
     McpDispatchOperation *dispatch_operation;
     McpDispatchOperationDelay *delay;
-    GSimpleAsyncResult *result;
 } PermissionContext;
 
 static void
@@ -106,15 +72,7 @@ permission_context_free (gpointer p)
 {
   PermissionContext *ctx = p;
 
-  if (ctx->delay != NULL)
-    mcp_dispatch_operation_end_delay (ctx->dispatch_operation, ctx->delay);
-
-  if (ctx->result != NULL)
-    {
-      g_simple_async_result_complete_in_idle (ctx->result);
-      g_object_unref (ctx->result);
-    }
-
+  mcp_dispatch_operation_end_delay (ctx->dispatch_operation, ctx->delay);
   g_object_unref (ctx->dispatch_operation);
   g_slice_free (PermissionContext, ctx);
 }
@@ -129,20 +87,9 @@ permission_cb (DBusPendingCall *pc,
   if (dbus_message_get_type (message) == DBUS_MESSAGE_TYPE_ERROR)
     {
       DEBUG ("Permission denied");
-
-      if (ctx->result != NULL)
-        {
-          g_simple_async_result_set_error (ctx->result, TP_ERROR,
-              TP_ERROR_PERMISSION_DENIED, "No, sorry");
-        }
-      else
-        {
-          G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-          mcp_dispatch_operation_leave_channels (ctx->dispatch_operation,
-              TRUE, TP_CHANNEL_GROUP_CHANGE_REASON_PERMISSION_DENIED,
-              "Computer says no");
-          G_GNUC_END_IGNORE_DEPRECATIONS
-        }
+      mcp_dispatch_operation_leave_channels (ctx->dispatch_operation,
+          TRUE, TP_CHANNEL_GROUP_CHANGE_REASON_PERMISSION_DENIED,
+          "Computer says no");
     }
   else
     {
@@ -232,107 +179,12 @@ finally:
   g_hash_table_unref (properties);
 }
 
-static void
-handler_is_suitable_async (McpDispatchOperationPolicy *self,
-    TpClient *recipient,
-    const gchar *unique_name,
-    McpDispatchOperation *dispatch_operation,
-    GAsyncReadyCallback callback,
-    gpointer user_data)
-{
-  GSimpleAsyncResult *simple = g_simple_async_result_new ((GObject *) self,
-      callback, user_data, handler_is_suitable_async);
-  GHashTable *properties = mcp_dispatch_operation_ref_nth_channel_properties (
-      dispatch_operation, 0);
-  PermissionContext *ctx = NULL;
-
-  DEBUG ("enter");
-
-  if (properties == NULL)
-    {
-      DEBUG ("no channels!?");
-      goto finally;
-    }
-
-  /* currently this example just checks the first channel */
-
-  if (!tp_strdiff (tp_asv_get_string (properties,
-          TP_IFACE_CHANNEL ".TargetID"),
-        "policy@example.net"))
-    {
-      TpDBusDaemon *dbus_daemon = tp_dbus_daemon_dup (NULL);
-      DBusGConnection *gconn = tp_proxy_get_dbus_connection (dbus_daemon);
-      DBusConnection *libdbus = dbus_g_connection_get_connection (gconn);
-      DBusPendingCall *pc = NULL;
-      DBusMessage *message;
-
-      ctx = g_slice_new0 (PermissionContext);
-      ctx->dispatch_operation = g_object_ref (dispatch_operation);
-      ctx->result = simple;
-      /* take ownership */
-      simple = NULL;
-
-      /* in a real policy-mechanism you'd give some details, like the
-       * channel's properties or object path, and the name of the handler */
-      message = dbus_message_new_method_call ("com.example.Policy",
-          "/com/example/Policy", "com.example.Policy", "CheckHandler");
-
-      if (!dbus_connection_send_with_reply (libdbus, message,
-            &pc, -1))
-        {
-          g_error ("out of memory");
-        }
-
-      dbus_message_unref (message);
-
-      if (pc == NULL)
-        {
-          DEBUG ("got disconnected from D-Bus...");
-
-          goto finally;
-        }
-
-      /* pc is unreffed by permission_cb */
-
-      DEBUG ("Waiting for permission");
-
-      if (dbus_pending_call_get_completed (pc))
-        {
-          permission_cb (pc, ctx);
-          goto finally;
-        }
-
-      if (!dbus_pending_call_set_notify (pc, permission_cb, ctx,
-            permission_context_free))
-        {
-          g_error ("Out of memory");
-        }
-
-      /* ctx will be freed later */
-      ctx = NULL;
-  }
-
-finally:
-  if (ctx != NULL)
-    permission_context_free (ctx);
-
-  g_hash_table_unref (properties);
-
-  if (simple != NULL)
-    {
-      g_simple_async_result_complete_in_idle (simple);
-      g_object_unref (simple);
-    }
-}
-
 static void
 cdo_policy_iface_init (McpDispatchOperationPolicyIface *iface,
     gpointer unused G_GNUC_UNUSED)
 {
-  iface->check = test_permission_plugin_check_cdo;
-
-  iface->handler_is_suitable_async = handler_is_suitable_async;
-  /* the default finish function accepts our GSimpleAsyncResult */
+  mcp_dispatch_operation_policy_iface_implement_check (iface,
+      test_permission_plugin_check_cdo);
 }
 
 typedef struct {
@@ -361,7 +213,7 @@ request_permission_cb (DBusPendingCall *pc,
     {
       DEBUG ("Permission denied");
       mcp_request_deny (ctx->request,
-          TP_ERROR, TP_CHANNEL_GROUP_CHANGE_REASON_PERMISSION_DENIED,
+          TP_ERRORS, TP_CHANNEL_GROUP_CHANGE_REASON_PERMISSION_DENIED,
           "Computer says no");
     }
   else
@@ -514,11 +366,9 @@ test_rejection_plugin_check_cdo (McpDispatchOperationPolicy *policy,
   else if (!tp_strdiff (target_id, "mc.hammer@example.net"))
     {
       DEBUG ("MC Hammer detected, leaving channels when observers have run");
-      G_GNUC_BEGIN_IGNORE_DEPRECATIONS
       mcp_dispatch_operation_leave_channels (dispatch_operation, TRUE,
           TP_CHANNEL_GROUP_CHANGE_REASON_PERMISSION_DENIED,
           "Can't touch this");
-      G_GNUC_END_IGNORE_DEPRECATIONS
     }
 
   g_hash_table_unref (properties);
@@ -528,7 +378,8 @@ static void
 rej_cdo_policy_iface_init (McpDispatchOperationPolicyIface *iface,
     gpointer unused G_GNUC_UNUSED)
 {
-  iface->check = test_rejection_plugin_check_cdo;
+  mcp_dispatch_operation_policy_iface_implement_check (iface,
+      test_rejection_plugin_check_cdo);
 }
 
 static void
@@ -544,7 +395,7 @@ test_rejection_plugin_check_request (McpRequestPolicy *policy,
         "com.example.ForbiddenChannel"))
     {
       DEBUG ("Forbidden channel detected, denying request");
-      mcp_request_deny (request, TP_ERROR, TP_ERROR_PERMISSION_DENIED,
+      mcp_request_deny (request, TP_ERRORS, TP_ERROR_PERMISSION_DENIED,
           "No, you don't");
     }
 
@@ -553,7 +404,7 @@ test_rejection_plugin_check_request (McpRequestPolicy *policy,
         NULL, NULL))
     {
       DEBUG ("Forbidden channel detected, denying request");
-      mcp_request_deny (request, TP_ERROR, TP_ERROR_PERMISSION_DENIED,
+      mcp_request_deny (request, TP_ERRORS, TP_ERROR_PERMISSION_DENIED,
           "No, you don't");
     }
 
@@ -578,25 +429,13 @@ mcp_plugin_ref_nth_object (guint n)
   switch (n)
     {
     case 0:
-      return g_object_new (test_no_op_plugin_get_type (),
-          NULL);
-
-    case 1:
       return g_object_new (test_permission_plugin_get_type (),
           NULL);
 
-    case 2:
+    case 1:
       return g_object_new (test_rejection_plugin_get_type (),
           NULL);
 
-    case 3:
-      return g_object_new (test_no_op_plugin_get_type (),
-          NULL);
-
-    case 4:
-      return g_object_new (test_dbus_account_plugin_get_type (),
-          NULL);
-
     default:
       return NULL;
     }
